@@ -191,7 +191,7 @@ package_vignettes <- function(path = ".") {
   if (!dir_exists(base)) {
     vig_path <- character()
   } else {
-    vig_path <- dir_ls(base, regexp = "\\.[rR]md$", recursive = TRUE)
+    vig_path <- dir_ls(base, regexp = "\\.[rR]md$", recurse = TRUE)
   }
   vig_path <- path_rel(vig_path, base)
   vig_path <- vig_path[!grepl("^_", path_file(vig_path))]
