@@ -28,9 +28,15 @@ flatten_para <- function(x, ...) {
   after_break <- c(FALSE, before_break[-length(x)])
   groups <- cumsum(before_break | after_break)
 
-  html <- purrr::map_chr(x, as_html, ...)
+  html <- purrr::map(x, as_html, ...)
+  # split at line breaks for everything except blocks
+  empty <- purrr::map_lgl(x, purrr::is_empty)
+  needs_split <- !is_block & !empty
+  html[needs_split] <- purrr::map(html[needs_split], split_at_linebreaks)
+
   blocks <- html %>%
     split(groups) %>%
+    purrr::map(unlist) %>%
     purrr::map_chr(paste, collapse = "")
 
   # There are three types of blocks:
@@ -92,7 +98,7 @@ as_html.USERMACRO <-  function(x, ...) ""
 as_html.tag_subsection <- function(x, ...) {
   paste0(
     "<h3>", flatten_text(x[[1]], ...), "</h3>\n",
-    flatten_text(x[[2]], ...)
+    flatten_para(x[[2]], ...)
   )
 }
 
@@ -273,13 +279,12 @@ as_html.tag_tabular <- function(x, ...) {
   col_sep <- class == "tag_tab"
   sep <- col_sep | row_sep
 
-  # Look for separators that have no text in front of them
-  no_text <- c(TRUE, class[-length(class)] != "TEXT")
-  keep <- !(sep & !no_text)
-  # data.frame(class, sep, no_text, keep)
-
-  cell_grp <- cumsum(keep)
-  cells <- unname(split(contents[keep], cell_grp[keep]))
+  # Identify groups in reverse order (preserve empty cells)
+  # Negative maintains correct ordering once reversed
+  cell_grp <- rev(cumsum(-rev(sep)))
+  cells <- unname(split(contents, cell_grp))
+  # Remove tailing content (that does not match the dimensions of the table)
+  cells <- cells[seq_len(length(cells) - length(cells)%%length(align))]
   cell_contents <- purrr::map_chr(cells, flatten_text, ...)
   cell_contents <- paste0("<td>", str_trim(cell_contents), "</td>")
   cell_contents <- matrix(cell_contents, ncol = length(align), byrow = TRUE)
@@ -324,7 +329,7 @@ as_html.tag_enumerate <- function(x, ...) {
 }
 #' @export
 as_html.tag_describe <- function(x, ...) {
-  paste0("<dl class='dl-horizontal'>\n", parse_descriptions(x[-1], ...), "</dl>")
+  paste0("<dl class='dl-horizontal'>\n", parse_descriptions(x[-1], ...), "\n</dl>")
 }
 
 # Effectively does nothing: only used by parse_items() to split up
@@ -461,9 +466,9 @@ tag_insert <- function(value) {
 #' @export
 as_html.tag_R <-        tag_insert('<span style="R">R</span>')
 #' @export
-as_html.tag_dots <-     tag_insert("&#8230;")
+as_html.tag_dots <-     tag_insert("...")
 #' @export
-as_html.tag_ldots <-    tag_insert("&#8230;")
+as_html.tag_ldots <-    tag_insert("...")
 
 #' @export
 as_html.tag_cr <-       tag_insert("<br >")
@@ -561,3 +566,14 @@ stop_bad_tag <- function(tag, msg = NULL) {
 
   stop(msg, call. = FALSE)
 }
+
+is_newline <- function(x, trim = FALSE) {
+  if (!inherits(x, "TEXT") && !inherits(x, "RCODE") && !inherits(x, "VERB"))
+    return(FALSE)
+
+  text <- x[[1]]
+  if (trim) {
+    text <- gsub("^[ \t]+|[ \t]+$", "", text)
+  }
+  identical(text, "\n")
+}
