@@ -34,6 +34,12 @@ render_page <- function(pkg = ".", name, data, path = "", depth = NULL, quiet =
   data$has_favicons <- has_favicons(pkg)
   data$opengraph <- utils::modifyList(data_open_graph(pkg), data$opengraph %||% list())
 
+  # The real location of 404.html is dynamic (#1129).
+  # Relative root does not work, use the full URL if available.
+  if(identical(path, "404.html") && length(pkg$meta$url)){
+    data$site$root <- paste0(pkg$meta$url, "/")
+  }
+
   # render template components
   pieces <- c("head", "navbar", "header", "content", "docsearch", "footer")
 
@@ -119,7 +125,7 @@ template_path <- function(pkg = ".") {
 }
 
 render_template <- function(path, data) {
-  template <- read_lines(path)
+  template <- read_file(path)
   if (length(template) == 0)
     return("")
 
